﻿using Syncfusion.UI.Xaml.Schedule;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace ScheduleAnimation_Wpf
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    #region Main Class

    public partial class MainWindow : Window
    {
        #region Constructor

        public MainWindow()
        {
            InitializeComponent();
            cmb_ScheduleType.ItemsSource = Enum.GetValues(typeof(ScheduleType));
            Schedule.ScheduleTypeChanging += Schedule_ScheduleTypeChanging;
            this.DataContext = this;
        }

        #endregion

        #region ScheduleTypeChanging Event
        void Schedule_ScheduleTypeChanging(object sender, ScheduleTypeChangingEventArgs e)
        {
            double fromoffset = 0.9;
            ScheduleType[] typecollection = Enum.GetValues(typeof(ScheduleType)) as ScheduleType[];
            ScheduleType oldvalue = (ScheduleType)e.OldValue;
            ScheduleType newvalue = (ScheduleType)e.NewValue;
            if (Array.IndexOf(typecollection, oldvalue) < Array.IndexOf(typecollection, newvalue))
            {
                fromoffset = 1.1;
            }
            else
            {
                fromoffset = 0.9;
            }
            ItemsControl items_ctrl = Schedule.FindElementOfType<ItemsControl>();
            Grid grid = items_ctrl.Items[1] as Grid;
            ContentControl con_ctrl = grid.Children[1] as ContentControl;
            Storyboard storyboard = new Storyboard();

            ScaleTransform scale = new ScaleTransform(1.0, 1.0);
            con_ctrl.RenderTransformOrigin = new Point(0.5, 0.5);
            con_ctrl.RenderTransform = scale;

            DoubleAnimation mScaleXButton = new DoubleAnimation();
            mScaleXButton.Duration = TimeSpan.FromMilliseconds(350);
            mScaleXButton.From = fromoffset;
            mScaleXButton.To = 1;
            storyboard.Children.Add(mScaleXButton);

            Storyboard.SetTargetProperty(mScaleXButton, new PropertyPath("RenderTransform.ScaleX"));

            DoubleAnimation mScaleYButton = new DoubleAnimation();
            mScaleYButton.Duration = TimeSpan.FromMilliseconds(350);
            mScaleYButton.From = fromoffset;
            mScaleYButton.To = 1;
            storyboard.Children.Add(mScaleYButton);

            Storyboard.SetTargetProperty(mScaleYButton, new PropertyPath("RenderTransform.ScaleY"));
            Storyboard.SetTarget(mScaleXButton, con_ctrl);
            Storyboard.SetTarget(mScaleYButton, con_ctrl);

            storyboard.Begin();

        }
        #endregion

        #region Button Click Event

        private void PART_PrevButton_Click(object sender, RoutedEventArgs e)
        {
            ItemsControl items_ctrl = Schedule.FindElementOfType<ItemsControl>();
            Grid grid = items_ctrl.Items[1] as Grid;
            ContentControl con_ctrl = grid.Children[1] as ContentControl;

            TranslateTransform trans_tran = new TranslateTransform(0, 0);
            con_ctrl.RenderTransformOrigin = new Point(0.5, 0.5);
            con_ctrl.RenderTransform = trans_tran;
            Storyboard storyboard = new Storyboard();


            Storyboard sb = new Storyboard();

            DoubleAnimation scaleX = new DoubleAnimation();
            scaleX.To = 0;
            scaleX.From = -20;
            scaleX.Duration = new Duration(TimeSpan.FromMilliseconds(250));

            Storyboard.SetTarget(scaleX, con_ctrl);
            Storyboard.SetTargetProperty(scaleX, new PropertyPath("RenderTransform.X"));

            DoubleAnimation opacity = new DoubleAnimation();
            opacity.To = 1;
            opacity.From = 0;
            opacity.Duration = new Duration(TimeSpan.FromMilliseconds(250));

            Storyboard.SetTarget(opacity, con_ctrl);
            Storyboard.SetTargetProperty(opacity, new PropertyPath("Opacity"));

            sb.Children.Add(opacity);
            sb.Children.Add(scaleX);

            sb.Begin();

        }

        private void PART_NextButton_Click(object sender, RoutedEventArgs e)
        {

            ItemsControl items_ctrl = Schedule.FindElementOfType<ItemsControl>();
            Grid grid = items_ctrl.Items[1] as Grid;
            ContentControl con_ctrl = grid.Children[1] as ContentControl;

            TranslateTransform trans_tran = new TranslateTransform(0, 0);
            con_ctrl.RenderTransformOrigin = new Point(0.5, 0.5);
            con_ctrl.RenderTransform = trans_tran;
            Storyboard storyboard = new Storyboard();


            Storyboard sb = new Storyboard();

            DoubleAnimation scaleX = new DoubleAnimation();
            scaleX.To = 0;
            scaleX.From = 20;
            scaleX.Duration = new Duration(TimeSpan.FromMilliseconds(250));

            Storyboard.SetTarget(scaleX, con_ctrl);
            Storyboard.SetTargetProperty(scaleX, new PropertyPath("RenderTransform.X"));

            DoubleAnimation opacity = new DoubleAnimation();
            opacity.To = 1;
            opacity.From = 0;
            opacity.Duration = new Duration(TimeSpan.FromMilliseconds(250));

            Storyboard.SetTarget(opacity, con_ctrl);
            Storyboard.SetTargetProperty(opacity, new PropertyPath("Opacity"));

            sb.Children.Add(opacity);
            sb.Children.Add(scaleX);

            sb.Begin();

        }

        #endregion
    } 
    #endregion

    #region DependencyObjectExtensions class

    public static class DependencyObjectExtensions
    {
        #region FindElementOfType

        /// <summary>
        ///     Searches the sub tree of an element (including that element) 
        ///     for an element of a particular type.
        /// </summary>
        public static T FindElementOfType<T>(this FrameworkElement element) where T : FrameworkElement
        {
            var correctlyTyped = element as T;
            if (correctlyTyped != null)
                return correctlyTyped;
            if (element != null)
            {
                int numChildren = VisualTreeHelper.GetChildrenCount(element);
                for (int i = 0; i < numChildren; i++)
                {
                    var child = FindElementOfType<T>(VisualTreeHelper.GetChild(element, i) as FrameworkElement);
                    if (child != null)
                        return child;
                }
            }
            return null;
        }

        #endregion
    } 
    #endregion
}
